@@ -6,6 +6,12 @@ from .gemini_parallel import (
     AdvancedApiKeyManager,
 )
 from .gemini_media_processor import prepare_media_contents
+from .gemini_tts import (
+    GeminiTTSProcessor,
+    text_to_speech,
+    TTS_VOICES,
+    TTS_MODELS,
+)
 from . import types
 
 __all__ = [
@@ -13,5 +19,9 @@ __all__ = [
     "GeminiStreamingProcessor",
     "AdvancedApiKeyManager",
     "prepare_media_contents",
+    "GeminiTTSProcessor",
+    "text_to_speech",
+    "TTS_VOICES",
+    "TTS_MODELS",
     "types",
 ]
